
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.*;
import java.util.function.Predicate;

public class LogParser {
    public List<User> users;

    public void prettyPrint() {
        for (LogParser.User u : users) {
            System.out.println(u.prettyStr());
        }
    }

    static class User {
        int order;
        String name;
        int wucan = 0;
        int wancan = 0;
        int totalDay = 0;
        int validDay = 0;
        int D = 0;
        double R;
        double A;
        double dur = 0D;

        double totalBu = 0;

        public User setName(String name) {
            this.name = name.replaceAll("\"", "");

            return this;
        }

        public void calTotalBu() {
            totalBu = wucan + wancan + D * 25 + R * 600 + A * 300;
        }

        public User setOrder(String order) {
            this.order = Integer.valueOf(order.replaceAll("\"", ""));
            return this;
        }

        public String prettyStr() {
            calTotalBu();
            return String.format("%s wucan:%d wancan:%d totalDay:%d validDay:%d dur:%.2f D:%d R:%.2f A:%.2f total:%.2f", name, wucan, wancan, totalDay, validDay, dur, D, R, A, totalBu);
        }
    }

    public static void main(String[] args) {

        if (args.length >= 2) {
            LogParser logParser = new LogParser();
            logParser.go(args[0], args[1]);
            logParser.prettyPrint();
        } else {
            System.out.println("usage: java -jar xx.jar ztolog.csv randa.csv");
        }

    }

    public void go(String ztoFile, String randaFile) {
        try {
            Scanner sc = new Scanner(new FileInputStream(ztoFile));
            sc.nextLine();
            Map<String, User> user = new HashMap<>();
            for (; sc.hasNextLine(); ) {
                String line = sc.nextLine();
                String[] tabs = line.split("\t");
                String date = tabs[5];
                String name = tabs[3];
                name = name.replaceAll("\"", "");
                String from = tabs[9];
                String to = tabs[10];
                String order = tabs[1];
                if (!user.containsKey(name))
                    user.put(name, new User().setName(name).setOrder(order));
                User u = user.get(name);
                u.totalDay++;
                if (!to.contains(":") || !from.contains(":")) {
                    continue;
                }
                //  System.out.println(line);
                double dur = calDate(from, to);
                u.dur += dur;

                if (dur >= 6) {
                    u.validDay++;
                    u.wucan += 25;
                }
                if (dur >= 8.5 && getTime(from) <= getTime("09:30")) u.D++;
                if (dur >= 12) u.wancan += 35;
                System.out.println(String.format("%s\t%s\t%s\t%s\t%.2f", date, name, from, to, dur));
            }
            for (Scanner jxsc = new Scanner(new FileInputStream(randaFile)); jxsc.hasNextLine(); ) {
                String line = jxsc.nextLine();
                String[] lines = line.split(" ");
                if (lines.length < 3) continue;
                User u = user.get(lines[0]);
                u.R = Double.valueOf(lines[1]);
                u.A = Double.valueOf(lines[2]);
            }
            String fil = "0,1,2,3,4,6,14";
            users = new ArrayList<>();
            users.addAll(user.values());
            users.removeIf(new Predicate<User>() {
                @Override
                public boolean test(User user) {
                    return fil.contains(user.order + "");
                }
            });
            for (User u : users)
                u.order = findOrder(u.order);
            calculateBu();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    public void calculateBu() {
        for (User u : users) {
            u.calTotalBu();
        }
        users.sort(new Comparator<User>() {
            @Override
            public int compare(User o1, User o2) {
                return o1.order - o2.order;
            }
        });
    }

    private int findOrder(int order) {
        for (int i = 0; i < map.length; i++)
            if (map[i] == order)
                return i;
        return -1;
    }

    static int[] map = new int[]{12, 11, 13, 10, 9, 5, 7, 8};

    private double getTime(String hourAndmin) {
        String[] s = hourAndmin.split(":");
        return Integer.valueOf(s[0]) * 60 + Integer.valueOf(s[1]);
    }

    private double calDate(String from, String to) {
        double frommin = getTime(from);
        double tomin = getTime(to);
        if (tomin < frommin) tomin += 24 * 60;
        return (tomin - frommin) / 60;
    }
}
